# Part 3: Post-processing with ParaView

The result file `example_rotationsymmetry.pvd` can be opened with the software [ParaView](https://www.paraview.org/).
To obtain a visualisation as shown in the introduction of this documented example, after loading
the result file, choose `Filters`>`Alphabetical`>`Rotational Extrusion`.
You might have to reset your view and switch to `3D`. Then apply `Filters`>`Alphabetical`>`Warp By Scalar`.
The result should look like this:

<figure>
    <center>
        <img src="../img/result.png" alt="Rotation-symmetric pressure distribution" width="60%"/>
        <figcaption> <b> Fig.1 - </b>Rotation-symmetric pressure distribution on a disc (warped to 3D)</figcaption>
    </center>
</figure>
